==> haskell-filestore-0.6.5-79-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-filestore.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 filestore
version:              0.6.5
visibility:           public
id:                   filestore-0.6.5-If7OQee8dt6GeLlQVGHAwK
key:                  filestore-0.6.5-If7OQee8dt6GeLlQVGHAwK
license:              BSD-3-Clause
maintainer:           jgm@berkeley.edu
author:               John MacFarlane, Gwern Branwen, Sebastiaan Visser
stability:            Experimental
synopsis:             Interface for versioning file stores.
description:
    The filestore library provides an abstract interface for a versioning
    file store, and modules that instantiate this interface.  Currently
    Git, Darcs, and Mercurial modules are provided, and other VCSs
    or databases could be added.

category:             Data
abi:                  061d6f91d707e22fdd1bf6553c05fd88
exposed:              True
exposed-modules:
    Data.FileStore Data.FileStore.Darcs Data.FileStore.Generic
    Data.FileStore.Git Data.FileStore.Mercurial Data.FileStore.Types
    Data.FileStore.Utils

hidden-modules:
    Data.FileStore.DarcsXml Data.FileStore.MercurialCommandServer
    Data.FileStore.Compat.Locale

import-dirs:          /usr/lib/ghc-9.4.8/site-local/filestore-0.6.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/filestore-0.6.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/filestore-0.6.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-filestore
hs-libraries:         HSfilestore-0.6.5-If7OQee8dt6GeLlQVGHAwK
depends:
    Diff-0.4.1-JbQUqnXfeqaHNgX8BS5WU4 base-4.17.2.1 bytestring-0.11.5.3
    containers-0.6.7 directory-1.3.7.1 filepath-1.4.2.2
    old-locale-1.0.0.7-KCPcWVOQKME2P4y4gxzvhh parsec-3.1.16.1
    process-1.6.18.0 split-0.2.5-m008juveJFC906Vg2goUt time-1.12.2
    utf8-string-1.0.2-D0oARDqSiCF3CIA0pPBIDm
    xml-1.3.14-Lx2FeToC7XoDX0aDGC9dRG

haddock-interfaces:   /usr/share/doc/haskell-filestore/html/filestore.haddock
haddock-html:         /usr/share/doc/haskell-filestore/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-filestore-0.6.5-80-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-filestore.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 filestore
version:              0.6.5
visibility:           public
id:                   filestore-0.6.5-JkbqzL2NSAZHnbtaOYdtWn
key:                  filestore-0.6.5-JkbqzL2NSAZHnbtaOYdtWn
license:              BSD-3-Clause
maintainer:           jgm@berkeley.edu
author:               John MacFarlane, Gwern Branwen, Sebastiaan Visser
stability:            Experimental
synopsis:             Interface for versioning file stores.
description:
    The filestore library provides an abstract interface for a versioning
    file store, and modules that instantiate this interface.  Currently
    Git, Darcs, and Mercurial modules are provided, and other VCSs
    or databases could be added.

category:             Data
abi:                  808a5b736ed1a30067bc6927b330f6da
exposed:              True
exposed-modules:
    Data.FileStore Data.FileStore.Darcs Data.FileStore.Generic
    Data.FileStore.Git Data.FileStore.Mercurial Data.FileStore.Types
    Data.FileStore.Utils

hidden-modules:
    Data.FileStore.DarcsXml Data.FileStore.MercurialCommandServer
    Data.FileStore.Compat.Locale

import-dirs:          /usr/lib/ghc-9.4.8/site-local/filestore-0.6.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/filestore-0.6.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/filestore-0.6.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-filestore
hs-libraries:         HSfilestore-0.6.5-JkbqzL2NSAZHnbtaOYdtWn
depends:
    Diff-0.4.1-LlG9CqI0BWmDdGO3rVr0iN base-4.17.2.1 bytestring-0.11.5.3
    containers-0.6.7 directory-1.3.7.1 filepath-1.4.2.2
    old-locale-1.0.0.7-KCPcWVOQKME2P4y4gxzvhh parsec-3.1.16.1
    process-1.6.18.0 split-0.2.5-KcBaumhT6eFHklJKzsytdC time-1.12.2
    utf8-string-1.0.2-D0oARDqSiCF3CIA0pPBIDm
    xml-1.3.14-Lx2FeToC7XoDX0aDGC9dRG

haddock-interfaces:   /usr/share/doc/haskell-filestore/html/filestore.haddock
haddock-html:         /usr/share/doc/haskell-filestore/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
